<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.5.2
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */
add_action( 'tgmpa_register', 'my_theme_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register five plugins:
 * - one included with the TGMPA library
 * - two from an external source, one from an arbitrary source, one from a GitHub repository
 * - two from the .org repo, where one demonstrates the use of the `is_callable` argument
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function my_theme_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */

	$theme_required_plugin_lists = array();
	$unyson_plugin = array();
	$url = 'https://api.wordpress.org/plugins/info/1.0/unyson';
	$api_response = wp_remote_get( $url );
	if ( is_array( $api_response ) && ! is_wp_error( $api_response ) ) {
		if( isset($api_response['response']) && !empty($api_response['response']) ) {
			if ( 404 == $api_response['response']['code'] && 'Not Found' == $api_response['response']['message'] ) {
				$unyson_plugin = array(
					array(
						'name'               => esc_html__('Unyson', 'mountcool'),
						'slug'               => 'unyson',
						'source'             => get_stylesheet_directory() . '/framework/plugins/unyson.zip',
						'required'           => true,
						'version'            => '2.7.28',
						'force_activation'   => false,
						'force_deactivation' => false,
					)
				);
			} else {
				$unyson_plugin = array(
					array(
						'name'     => esc_html__('Unyson', 'mountcool'),
						'slug'     => 'unyson',
						'required' => true,
					)
				);
			}
		}
	}

	$plugins = array(

		// This is an example of how to include a plugin bundled with a theme.
		array(
			'name'     			=> esc_html('DesignThemes Core  Shortcode Plugins','mountcool'), // The plugin name
			'slug'     			=> 'designthemes-core-features', // The plugin slug (typically the folder name)
			'source'   			=> get_stylesheet_directory() . '/framework/plugins/designthemes-core-features.zip', // The plugin source
			'required' 			=> true, // If false, the plugin is only 'recommended' instead of required
			'version' 			=> '2.2', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
			'external_url' 		=> '', // If set, overrides default API URL and points to an external URL
		),
		
		array(
			'name'     			=> esc_html('Responsive Styled Google Maps Generator','mountcool'),
			'slug'     			=> 'responsive-maps-plugin',
			'source'   			=> get_theme_file_uri('/framework/plugins/responsive-maps-plugin.zip'),
			'version' 			=> '5.0',
			'required' 			=> false,
		),

		array(
			'name' 				=> esc_html('Contact Form 7','mountcool'),
			'slug' 				=> 'contact-form-7',
			'required' 			=> false,
		),
		
		array(
			'name' 				=> esc_html('Like This','mountcool'),
			'slug' 				=> 'roses-like-this',
			'required' 			=> false,
		),

		array(
			'name'				=>	esc_html('WooCommerce - excelling eCommerce','mountcool'),
			'slug'				=>	'woocommerce',
			'required'			=>	false
		),

		array(
			'name'				=>	esc_html('YITH WooCommerce Wishlist','mountcool'),
			'slug'				=>	'yith-woocommerce-wishlist',
			'required'			=>	false
		),

	);

	$args = array(
		'user-agent' => 'WordPress/' . get_bloginfo( 'version' ) . '; ' . network_site_url(),
		'timeout'    => 30,
	);

	$response = wp_remote_get( 'http://wedesignthemes.com/plugins/designthemes/version5.php', $args );
	$data = json_decode( wp_remote_retrieve_body( $response ), true );

	if ( is_array( $data ) && ! empty( $data ) ) {
		$updated_plugin_list = array_merge( $data, $plugins );
	} else {
		$updated_plugin_list = $plugins;
	}

	$theme_required_plugin_lists = array_merge( $unyson_plugin, $updated_plugin_list );

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'mountcool',             // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => true,                    // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $theme_required_plugin_lists, $config );

}